<?php

namespace Avos\Routes;
use Avos\Scaffold;

////////////////////////////////////////////////////////////////////////////
// redirect: issue 301
//

function redirect($path, $url)
{
	\redirect($url);
}

////////////////////////////////////////////////////////////////////////////
// none: user defined page
//

function none()
{
	\Avos\Scaffold\expandUrlMeta();
	return array();
}

////////////////////////////////////////////////////////////////////////////
// webcams: index
//

function webcams($args, $filter, $archive='')
{
    global $_AVOS;

	#echo "<pre>args="; print_r($args); echo "filter="; print_r($filter); exit;

    if ($archive) {
        $archive = 'Archive';
    }

	if (isset($_AVOS['config']['site']['remoteRpcUrl'])) {
		$webcams = \Avos\Rpc\call('webcams', $args, $filter);
		$_AVOS['page']['matches'] = $webcams['args']['matches'];
		return $webcams;
	}

	\Avos\Utils\profFlag("webcams()");

	if (isset($args['count'])) {
		// to allow calling like \Avos\Render\getWebcams('gender=f&count=8')
		$perPage = $args['count'];
		unset($args['count']);
	}
	else {
		$perPage = $_AVOS['config']['webcams']['perPage'];
	}

	$page = 1;

	if (isset($args['page'])) {
		$page = (int)$args['page'];
	}

	$offset = 0;

	if (!empty($page) && $page > 0) {
		$offset = $perPage * ($page - 1);
		$_AVOS['page']['page'] = $page;
	}
	else {
		$offset = 0;
		$_AVOS['page']['page'] = 1;
	}
	$WHERE = '';
	#echo "<pre>";print_r($args);echo "filter=$filter";exit;
	if (!empty($filter)) $WHERE = "WHERE $filter";

	//
	// sort order
	//

    $SORT = 'rank ASC';

	if (isset($args['sort'])) {
		switch ($args['sort']) {

			case 'random':
				$SORT = 'RAND()';
				break;

			case 'viewers':
				$SORT = 'viewers DESC';
				break;

			case 'leastviewers':
			case 'lviewers':
				$SORT = 'viewers ASC';
				break;

			case 'followers':
				$SORT = 'followers DESC';
				break;

			case 'followers':
			case 'lfollowers':
				$SORT = 'followers ASC';
				break;

			case 'oldest':
			case 'lyoungest':
				$SORT = 'age DESC';
				break;

			case 'youngest':
				$SORT = 'age ASC';
				break;

			case 'newest':
				$SORT = 'addedon DESC';
				break;

			case 'experienced':
			case 'veterans':
			case 'lnewest':
				$SORT = 'addedon ASC';
				break;

			case 'worstrank':
			case 'lrank':
				$SORT = 'rank DESC';
				break;

			case 'bestrank';
			case 'rank';
				// is the default
				break;

		}

        // else gets passed to expandUrlMeta()
        unset($args['sort']);
	}

	$sql = "
		SELECT SQL_CALC_FOUND_ROWS *
		FROM webcams$archive
		$WHERE
		ORDER BY $SORT
		LIMIT $perPage
		OFFSET $offset
";

	$models = \Avos\Database\queryAssoc($sql);
    $matches = \Avos\Database\foundRows();

    if (isset($_AVOS['page']['type']) && $_AVOS['page']['type'] == 'webcams' && $offset == 0 && $matches > 1) {
        \Avos\Users\saveSearch($args, $filter);
    }

    $indexPagesRedisData = getConfig('webcams', 'indexPagesRedisData', 0);

	foreach ($models as $i => $m) {
        $models[$i]['imagePath'] = \Avos\Utils\imagePath($m);
        $models[$i]['siteShortName'] = $models[$i]['site'];
        $models[$i]['siteShortNameCaps'] = ucfirst($models[$i]['site']);
		$models[$i]['site'] = \Avos\Scaffold\expandSiteName($models[$i]['site']);
		$models[$i]['status'] = \Avos\Scaffold\expandStatus($models[$i]['status']);
		$models[$i]['gender'] = \Avos\Scaffold\expandGender($models[$i]['gender']);

		if ($m['age'] == 0) {
			$models[$i]['age'] = '';
		}

		//
		// merge in any redis data
		//

        if ($indexPagesRedisData) {
            $extra = \Avos\Redis\getModel($m['id']);
            foreach ($extra as $k => $v) {
                $models[$i][$k] = $v;
            }
        }
	}

	$_AVOS['page']['matches'] = $matches;
	$_AVOS['page']['pages'] = (int)($matches / $_AVOS['config']['webcams']['perPage']) + 1;

	// dont call expandUrlMeta() unless the actual url is 'webcams'
	// e.g: don't call if within getRelatedWebcams()

	$page = \getUrlMatched();
	if (isset($page['type']) && $page['type'] == 'webcams') {
		\Avos\Scaffold\expandUrlMeta($args);
	}

	\Avos\Utils\profFlag("webcams() done");

	return array(
		'args' => array( 
			'models' => $models,
			'matches' => $matches
		)
	);
}

////////////////////////////////////////////////////////////////////////////
// webcam: profile
//

function webcam($path, $filter, $archive=false)
{
	if (isset($_AVOS['config']['site']['remoteRpcUrl'])) {
		return \Avos\Rpc\call('webcam', $args, $filter);
	}

	//
	// decode filters from path like /:nickname/ and $filter like site='cb'
	//

	$where = array();

	if (isset($path['site'])) {
		$path['site'] = \Avos\Scaffold\shortSiteName($path['site']);
		$where[] = "site=\"$path[site]\"";
	}

	#echo "<pre>path="; print_r($path); echo "filter=$filter\n";

	/*
	if (isset($path['nickname'])) $where[] = "nickname=\"$path[nickname]\"";
	if (!empty($filter)) $where[] = $filter;
	$where = implode(" AND ", $where);
	if (!empty($where)) $where = "WHERE $where";
	*/

	if (!empty($filter)) $filter = "WHERE $filter";

	if ($archive !== false) {
		$ext = 'Archive';
		$filter = preg_replace('!^WHERE!', '', $filter) . " AND updatedOn != 0";
	}
	else {
		$ext = '';
	}

	#echo "SELECT * FROM webcams$ext $filter LIMIT 1<br>";
	$model = \Avos\Database\queryAssoc("SELECT * FROM webcams$ext $filter LIMIT 1");

	if (count($model) == 0) {

		// try the webcamsArchive table if not already

		if ($archive == false) {
			return webcam($path, $filter, true);
		}

		// trigger searching for 404 meta

		\Avos\Scaffold\expandUrlMeta();

		// issue 404

		return array(
			'template' => 'webcamNotFound.php',
			'args' => array(
				'message' => "Model Not Found"
			)
		);
	}

	$model = $model[0];
	$model['imagePath'] = \Avos\Utils\imagePath($model);
	$model['siteShortName'] = $model['site'];
	$model['siteShortNameCaps'] = ucfirst($model['site']);
	$model['site'] = \Avos\Scaffold\expandSiteName($model['site']);
	$model['status'] = \Avos\Scaffold\expandStatus($model['status']);
	$model['gender'] = \Avos\Scaffold\expandGender($model['gender']);
	$model['tags'] = str_replace(',', ', ', $model['tags']);
    $model['age'] = $model['age'] == 0 ? 18 : $model['age'];

    $tmp = unserialize($model['links']);
    $model['links'] = [];

    if (is_array($tmp)) {
        foreach ($tmp as $s) {
            if (preg_match('!https?://(www\.)?(.*?)\.com!', $s, $c)) {
                $model['links'][$c[2]] = $s;
            }
        }
    }

	#$heatmap = \Avos\Webcams\getHeatMap($model);
	####$stats = \Avos\Database\queryAssoc('SELECT * FROM monthlyStats WHERE webcamsId=:id ORDER BY id DESC', $model);
	#$stats = \Avos\Redis\getStats($model['id'], 'm', '*', '*', '*', true);
	#$head = \Avos\Scaffold\parsePhpTemplate('webcamsProfileHead.php', array('stats' => $stats, 'heatmap' => $heatmap));

	/*
	foreach ($stats as $i => $s) {
		$stats[$i]['totalTimeStr'] = \Avos\Utils\seconds2string($s['freechatTime']+$s['groupTime']+$s['privateTime']);
		$stats[$i]['freechatTimeStr'] = \Avos\Utils\seconds2string($s['freechatTime']);
		$stats[$i]['groupTimeStr'] = \Avos\Utils\seconds2string($s['groupTime']);
		$stats[$i]['privateTimeStr'] = \Avos\Utils\seconds2string($s['privateTime']);
	}
	*/

	//
	// merge in data from redis
	//

	$extra = \Avos\Redis\getModel($model['id']);

	foreach ($extra as $k => $v) {
		$model[$k] = $v;
	}

	//
	// set any meta
	//

    \Avos\Scaffold\expandUrlMeta($model);

    //
    // set numImages to 0 if needed as they will return a 404
    //

    if ($model['status'] == 'Offline') {
        foreach (explode(',', getConfig('webcams', 'hideOfflineImages', '')) as $s) {
            if ($model['siteShortName'] == $s) {
                $model['numImages'] = 0;
            }
        }
    }

    //
    // increment profile views
    //

    \Avos\Users\modelsProfileAction($model['id'], 'views');

	return array(
		'args' => array(
			'name' => $model['nickname'],
			#'stats' => $stats,
			'model' => $model,
			#'head' => $head
		)
	);
}

////////////////////////////////////////////////////////////////////////////
// rpc: fetch any data
//

function videos($args, $filter)
{
	global $_AVOS;

	//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	// total hack - query2sql will add in: status != 'o'
	// find a better way - 2nd arg to query2sql is expand categories
	#$filter = str_replace("AND status != 'o'", "", $filter);
	#$filter = str_replace("status != 'o'", "", $filter);
	//!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

	if (isset($args['count'])) {
		// to allow calling like \Avos\Render\getVideos('count=8')
		$perPage = $args['count'];
		unset($args['count']);
	}
	else {
		$perPage = $_AVOS['config']['videos']['perPage'];
	}

	$page = 1;

	if (isset($args['page'])) {
		$page = (int)$args['page'];
	}

	$offset = 0;

	if (!empty($page) && $page > 0) {
		$offset = $perPage * ($page - 1);
		$_AVOS['page']['page'] = $page;
	}
	else {
		$offset = 0;
		$_AVOS['page']['page'] = 1;
	}

	if (!preg_match('!^hidden!', $filter)) {
		$WHERE = "publishedOn > 0 ";

		if (!empty($filter)) {
			$WHERE .= " AND $filter";
		}
	}
	else {
		$WHERE = "publishedOn = 0";
	}

	// sort order
	$SORT = 'publishedOn DESC';

	if (isset($args['sort'])) {
		switch ($args['sort']) {

			case 'popular':
				$SORT = 'views DESC';
				break;

			case 'longest':
				$SORT = 'duration DESC';
				break;

			case 'viewed':
				$SORT = 'viewedOn DESC';
				break;

			case 'latest';
				// is the default
				break;
		}
	}

	// fetch the data
	\Avos\Database\setCacheTime($_AVOS['config']['videos']['cacheExpiry']);

	$videos = \Avos\Database\queryAssoc("
					SELECT SQL_CALC_FOUND_ROWS *
					FROM videos
					WHERE $WHERE
					ORDER BY $SORT
					LIMIT $perPage
					OFFSET $offset
				");

	$matches = \Avos\Database\foundRows();

	foreach ($videos as $i => $v) {
		$videos[$i]['imagePath'] = \Avos\Videos\videoPath($v['filename'], true);
		$videos[$i]['durationStr'] = \Avos\Utils\seconds2string($videos[$i]['duration'], true, true);
	}

	$_AVOS['page']['matches'] = $matches;
	$_AVOS['page']['pages'] = (int)($matches / $_AVOS['config']['videos']['perPage']) + 1;

	// dont call expandUrlMeta() unless the actual url is 'videos'
	// e.g: don't call if within getRelatedVideos()

	$page = \getUrlMatched();
	if ($page['type'] == 'videos') {
		\Avos\Scaffold\expandUrlMeta($args);
	}

	return array(
		'args' => array(
			'videos' => $videos
		)
	);
}

////////////////////////////////////////////////////////////////////////////
// video
//

function video($args, $filter)
{
	global $_AVOS;

	//
	// use id or title to match the video
	//

	if (isset($args['id'])) {
		$WHERE = "id=$args[id]";
	}
	else if (isset($args['urlTitle'])) {
		$WHERE = "urlTitle=" . \Avos\Database\quote($args['urlTitle']);
	}
	else {
		return array(
			'template' => 'notFound.php',
			'args' => array(
				'message' => "Video Not Found"
			)
		);
	}

	if (!preg_match('!^hidden!', $filter)) {
		$WHERE .= " AND publishedOn > 0 ";
	}
	else {
		$WHERE .= " AND publishedOn = 0 ";
	}

	//
	// extract and fixup data
	//

	\Avos\Database\setCacheTime($_AVOS['config']['videos']['cacheExpiry']);
	$chk = \Avos\Database\queryAssoc("SELECT * FROM videos WHERE $WHERE LIMIT 1");
	\Avos\Database\query("UPDATE videos SET views=views+1, viewedOn=UNIX_TIMESTAMP() WHERE $WHERE");

	if (count($chk) == 0) {
		return array(
			'template' => 'notFound.php',
			'args' => array(
				'message' => "Video Not Found"
			)
		);
	}

	$video = $chk[0];
	$video['imagePath'] = \Avos\Videos\videoPath($video['filename'], true);
	$video['durationStr'] = \Avos\Utils\seconds2string($video['duration'], true, true);

	/*
	if ($video['height'] < 720) {
		$video['width'] *= 2;
		$video['height'] *= 2;
	}
	*/


	$page = \getUrlMatched();
	if ($page['type'] == 'video') {
		\Avos\Scaffold\expandUrlMeta($video);
	}

	// need to convert to array after setting url meta for tags
	$video['tags'] = explode(',', $video['tags']);

	return array(
		'args' => array(
			'video' => $video
		)
	);
}

////////////////////////////////////////////////////////////////////////////
// photos
//

function photos($args, $filter)
{
	global $_AVOS;

	if (isset($args['count'])) {
		// to allow calling like \Avos\Render\getVideos('count=8')
		$perPage = $args['count'];
		unset($args['count']);
	}
	else {
		$perPage = $_AVOS['config']['photos']['perPage'];
	}

	$page = 1;

	if (isset($args['page'])) {
		$page = (int)$args['page'];
	}

	$offset = 0;

	if (!empty($page) && $page > 0) {
		$offset = $perPage * ($page - 1);
		$_AVOS['page']['page'] = $page;
	}
	else {
		$offset = 0;
		$_AVOS['page']['page'] = 1;
	}

	$WHERE = 'publishedOn>0';
	if (!empty($filter)) $WHERE .= " AND $filter";

	// fetch the data
	\Avos\Database\setCacheTime($_AVOS['config']['photos']['cacheExpiry']);

	// sort order
	$SORT = 'publishedOn DESC';

	if (isset($args['sort'])) {
		switch ($args['sort']) {

			case 'popular':
				$SORT = 'views DESC';
				break;

			case 'total':
				$SORT = 'numPhotos DESC';
				break;

			case 'viewed':
				$SORT = 'viewedOn DESC';
				break;

			case 'latest';
				// is the default
				break;
		}
	}

	$photos = \Avos\Database\queryAssoc("
					SELECT SQL_CALC_FOUND_ROWS *
					FROM photos
					WHERE $WHERE
					ORDER BY $SORT
					LIMIT $perPage
					OFFSET $offset
				");

	foreach ($photos as $i => $p) {
		$photos[$i]['imagePath'] = \Avos\Photos\photoPath($p['folder'], true);
	}

	$matches = \Avos\Database\foundRows();
	$_AVOS['page']['matches'] = $matches;
	$_AVOS['page']['pages'] = (int)($matches / $_AVOS['config']['photos']['perPage']) + 1;

	$page = \getUrlMatched();
	if ($page['type'] == 'photos') {
		\Avos\Scaffold\expandUrlMeta($args);
	}

	return array(
		'args' => array(
			'photos' => $photos
		)
	);
}

////////////////////////////////////////////////////////////////////////////
// photo
//

function photo($args, $filter)
{
	global $_AVOS;

	//
	// use id or title to match the video
	//

	if (isset($args['id'])) {
		$WHERE = "id=$args[id]";
	}
	else if (isset($args['urlTitle'])) {
		$WHERE = "urlTitle=" . \Avos\Database\quote($args['urlTitle']);
	}
	else {
		return array(
			'template' => 'notFound.php',
			'args' => array(
				'message' => "Gallery Not Found"
			)
		);
	}

	//
	// extract and fixup data
	//

	\Avos\Database\setCacheTime($_AVOS['config']['photos']['cacheExpiry']);
	$chk = \Avos\Database\queryAssoc("SELECT * FROM photos WHERE $WHERE AND publishedOn > 0 LIMIT 1");
	\Avos\Database\query("UPDATE photos SET views=views+1, viewedOn=UNIX_TIMESTAMP() WHERE $WHERE");

	if (count($chk) == 0) {
		return array(
			'template' => 'notFound.php',
			'args' => array(
				'message' => "Gallery Not Found"
			)
		);
	}

	$photos = $chk[0];
	$photos['imagePath'] = \Avos\Photos\photoPath($photos['folder'], true);

	$page = \getUrlMatched();
	if ($page['type'] == 'photo') {
		\Avos\Scaffold\expandUrlMeta($photos);
	}

	$photos['tags'] = explode(',', $photos['tags']);

	return array(
		'args' => array(
			'photos' => $photos
		)
	);
}

////////////////////////////////////////////////////////////////////////////
// users
//

function users($args, $filter)
{
    // convert from sql format to array

    $args = [];
    foreach (explode(' AND ', $filter) as $f) {
        if (preg_match('!(\w+)\s*=\s*"([\w\-]+)"!', $f, $ff)) {
            $args[$ff[1]] = $ff[2];
        }
    }

    $ret = \Avos\Users\action($args);

    //
    // check for json output
    //

    if (!empty($args['format']) && $args['format'] == 'json') {
        header('Content-type: application/json');
        echo json_encode($ret);
        exit;
    }
    elseif (!empty($args['format']) && $args['format'] == 'print') {
        header('Content-type: text/plain');
        print_r($ret);
        exit;
    }

    //
    // return data to process via template
    //

	return $ret;
}

////////////////////////////////////////////////////////////////////////////
// escorts: index
//

function escorts($args, $filter)
{
    global $_AVOS;

    $WHERE = "approved=1";
    $SORT = "nickname";
    $perPage = getConfig('escorts', 'perPage', 30);
    $offset = 0;

	$escorts = \Avos\Database\queryAssoc("
					SELECT SQL_CALC_FOUND_ROWS *
					FROM escorts
					WHERE $WHERE
					ORDER BY $SORT
					LIMIT $perPage
					OFFSET $offset
				");

	foreach ($escorts as $i => $e) {
		#$photos[$i]['imagePath'] = \Avos\Escorts\photoPath($e['folder'], true);
	}

	$matches = \Avos\Database\foundRows();
	$_AVOS['page']['matches'] = $matches;
	$_AVOS['page']['pages'] = (int)($matches / $perPage) + 1;

	$page = \getUrlMatched();
	if ($page['type'] == 'escorts') {
		\Avos\Scaffold\expandUrlMeta($args);
	}

	return array(
		'args' => array(
			'escorts' => $escorts
		)
	);
}

////////////////////////////////////////////////////////////////////////////
// escort: profile
//

function escort($path, $filter, $archive=false)
{
    global $_AVOS;

	//
	// use id or title to match the video
	//

	if (isset($args['id'])) {
		$WHERE = "id=$args[id]";
	}
	else if (isset($args['urlTitle'])) {
		$WHERE = "nickname=" . \Avos\Database\quote($args['nickname']);
	}
	else {
		return array(
			'template' => 'notFound.php',
			'args' => array(
				'message' => "Escort Not Found"
			)
		);
	}

	//
	// extract and fixup data
	//

	\Avos\Database\setCacheTime(getConfig('escorts', 'cacheExpiry', 60));
	$chk = \Avos\Database\queryAssoc("SELECT * FROM escorts WHERE $WHERE AND approved = 0 LIMIT 1");
	\Avos\Database\query("UPDATE escorts SET views=views+1, viewedOn=UNIX_TIMESTAMP() WHERE $WHERE");

	if (count($chk) == 0) {
		return array(
			'template' => 'notFound.php',
			'args' => array(
				'message' => "Escort Not Found"
			)
		);
	}

	$escort = $chk[0];
	#$escort['imagePath'] = \Avos\Escorts\photoPath($photos['folder'], true);

	$page = \getUrlMatched();
	if ($page['type'] == 'escort') {
		\Avos\Scaffold\expandUrlMeta($escort);
	}

	$escort['tags'] = explode(',', $escort['tags']);

	return array(
		'args' => array(
			'escort' => $escort
		)
	);
}

////////////////////////////////////////////////////////////////////////////
// posts: index
//

function posts($args, $filter)
{
    global $_AVOS;

    $WHERE = "publishedOn>0";

    if (!empty($filter)) {
        $WHERE .= " AND $filter";
    }

    $SORT = "publishedOn DESC";
    $url = \getUrlMatched();
    $perPage = getConfig('posts', 'perPage', 30);
    $page = $url['page'];
    $offset = ($page-1) * $perPage;

    $sql = "SELECT SQL_CALC_FOUND_ROWS *
            FROM posts
            WHERE $WHERE
            ORDER BY $SORT
            LIMIT $perPage
            OFFSET $offset";

    $pages = \Avos\Database\queryAssoc($sql);

    foreach ($pages as $i => $p) {
        $pages[$i]['tags'] = explode(',', $p['tags']);
    }

	$matches = \Avos\Database\foundRows();
	$_AVOS['page']['matches'] = $matches;
	$_AVOS['page']['pages'] = (int)($matches / $perPage) + 1;

	if ($url['type'] == 'posts') {
		\Avos\Scaffold\expandUrlMeta($args);
	}

	return array(
		'args' => array(
			'posts' => $pages
		)
	);
}

////////////////////////////////////////////////////////////////////////////
// post
//

function post($args, $filter)
{
	global $_AVOS;

	//
	// merge in url args from [urls]
	//

	if (isset($args['id'])) {
		$WHERE = "id=$args[id]";
	}
	else if (isset($args['urlTitle'])) {
		$WHERE = "urlTitle=" . \Avos\Database\quote($args['urlTitle']);
    }
    else if (!empty($filter)) {
        $WHERE = $filter;
    }
	else {
		return array(
			'template' => 'notFound.php',
			'args' => array(
				'message' => "Page Not Found"
			)
		);
    }

	\Avos\Database\setCacheTime(getConfig('posts', 'cacheExpiry', 60));
	$chk = \Avos\Database\queryAssoc("SELECT * FROM posts WHERE $WHERE LIMIT 1");
    \Avos\Database\query("UPDATE posts SET views=views+1, viewedOn=UNIX_TIMESTAMP() WHERE $WHERE");

	if (count($chk) == 0) {
		return array(
			'template' => 'notFound.php',
			'args' => array(
				'message' => "Page Not Found"
			)
		);
	}

	$post = $chk[0];
    $post['tags'] = explode(',', $post['tags']);

	if (getUrlMatched()['type'] == 'post') {
		\Avos\Scaffold\expandUrlMeta($args);
	}

	return array(
		'args' => array(
			'post' => $post
		)
	);
}

////////////////////////////////////////////////////////////////////////////
// rpc: fetch any data
//

function rpc()
{
	global $_AVOS;

	if (!isset($_GET['k']) || $_GET['k'] != $_AVOS['config']['site']['rpcKey']) {

		header("HTTP/1.1 403 Denied");
		echo "403 Denied";
		exit;

	}

	return \Avos\Rpc\process();
}


// add by me 
// 
function casino()
{
	\Avos\Scaffold\expandUrlMeta();
	return array();
}


function promote($args, $filter)
{
    global $_AVOS;
    // Uncomment the line below for debugging purposes
    // print_r($_AVOS);
    // exit;

    if (isset($args['count'])) {
        // to allow calling like \Avos\Render\getVideos('count=8')
        $perPage = $args['count'];
        unset($args['count']);
    } else {
        $perPage = $_AVOS['config']['promote']['perPage']; // This should be 1
    }

    $page = 1;

    if (isset($args['page'])) {
        $page = (int)$args['page'];
    }

    $offset = 0;

    if (!empty($page) && $page > 0) {
        $offset = $perPage * ($page - 1);
        $_AVOS['page']['page'] = $page;
    } else {
        $offset = 0;
        $_AVOS['page']['page'] = 1;
    }

    // Query to retrieve a limited number of records (pagination)
    $limitQuery = "SELECT * FROM promote LIMIT $perPage OFFSET $offset";
    $promote = \Avos\Database\queryAssoc($limitQuery);

    // Query to retrieve a limited number of records from promoteMainDescription (pagination if needed)
    $limitQueryMain = "SELECT * FROM promoteMainDescription LIMIT $perPage OFFSET $offset";
    $promoteMain = \Avos\Database\queryAssoc($limitQueryMain);

    // Return the results as an array
    return array(
        'args' => array(
            'promote' => $promote,
            'promoteMain' => $promoteMain
        )
    );
}

function promot($args, $filter)
{
    global $_AVOS;

    if (isset($args['siteId'])) {
        $siteId = (int)$args['siteId'];
        $WHERE = "siteId = $siteId";
    } elseif (isset($args['siteNames'])) {
        $siteNames = \Avos\Database\quote($args['siteNames']);
        $WHERE = "siteNames = $siteNames";
    } else {
        // Handle the case where neither siteId nor siteNames is provided
        // You may want to add appropriate error handling or default behavior
        return array();
    }

    \Avos\Database\setCacheTime($_AVOS['config']['photos']['cacheExpiry']);
    $promot = \Avos\Database\queryAssoc("SELECT * FROM promote WHERE $WHERE");

    // Check if any records were found
    if (empty($promot)) {
        // Handle the case where no matching records were found
        // You may want to add appropriate error handling or default behavior
        return array();
    }

    // Assuming you want to return only the first matching record
    $promot = $promot[0];

    $page = \getUrlMatched();
    if ($page['type'] == 'promot') {
        \Avos\Scaffold\expandUrlMeta($promot);
    }

    return array(
        'args' => array(
            'promot' => $promot
        )
    );
}





//////////////////////////////
//// blogs
//
function blogs($args, $filter)
{
	global $_AVOS;

	if (isset($args['count'])) {
		// to allow calling like \Avos\Render\getVideos('count=8')
		$perPage = $args['count'];
		unset($args['count']);
	}
	else {
		$perPage = $_AVOS['config']['blogs']['perPage'];
	}

	$page = 1;

	if (isset($args['page'])) {
		$page = (int)$args['page'];
	}

	$offset = 0;

	if (!empty($page) && $page > 0) {
		$offset = $perPage * ($page - 1);
		$_AVOS['page']['page'] = $page;
	}
	else {
		$offset = 0;
		$_AVOS['page']['page'] = 1;
	}

	$WHERE = 'publishedOn>0';
	if (!empty($filter)) $WHERE .= " AND $filter";

	// fetch the data
	\Avos\Database\setCacheTime($_AVOS['config']['publishedOn']['cacheExpiry']);

	// sort order
	$SORT = 'publishedOn DESC';

	if (isset($args['sort'])) {
		switch ($args['sort']) {

		case 'popular':
				$SORT = 'views DESC';
				break;

			case 'total':
				$SORT = 'numPhotos DESC';
				break;

			case 'viewed':
				$SORT = 'viewedOn DESC';
				break;

			case 'latest';
				// is the default
				break;
		}
	}


	$blogs = \Avos\Database\queryAssoc("
    SELECT *
    FROM ArticleBlogPosts
    WHERE publishedOn > 0
    ORDER BY id 
");

foreach ($blogs as $i => $b) {
    $blogs[$i]['imagePath'] = $_AVOS['config']['blog']['blogPhotosUrl'];
	$blogs[$i]['blogGalleryUrl'] = $_AVOS['config']['blog']['blogGalleryUrl'];
}

$matches = \Avos\Database\foundRows();
$_AVOS['page']['matches'] = $matches;

$pageCount = ceil($matches / $_AVOS['config']['blogs']['perPage']);
$_AVOS['page']['pages'] = $pageCount;

$page = \getUrlMatched();
if ($page['type'] == 'blogs') {
    \Avos\Scaffold\expandUrlMeta($args);
}

return array(
    'args' => array(
        'blogs' => $blogs
    )
);

}

//
//  $title = \Avos\Database\quote($args['Title']);
//$condition = "Title = $title";
//
//$blog = \Avos\Database\queryAssoc("SELECT * FROM ArticleBlogPosts WHERE $condition AND publishedOn > 0 LIMIT 1");
//$blog = $blog[0];



function blog($args, $filter)
{
    global $_AVOS;
	//print_r($_AVOS);exit;
	//
	// use id or title to match the video
	//

	if (isset($args['id'])) {
		$WHERE = "id=$args[id]";
	}
	else if (isset($args['urlTitle'])) {
		$title = \Avos\Database\quote($args['Title']);
		$WHERE = "Title = $title";
	}
	

	//
	// extract and fixup data
	//

	
	\Avos\Database\setCacheTime($_AVOS['config']['photos']['cacheExpiry']);
	$blog = \Avos\Database\queryAssoc("SELECT * FROM ArticleBlogPosts WHERE $WHERE AND publishedOn > 0 LIMIT 1");
	


//print_r($WHERE);exit;

	$blog = $blog[0];
	
	\Avos\Database\query("UPDATE ArticleBlogPosts SET Views = Views + 1 WHERE id = {$blog['id']}");
	
	$page = \getUrlMatched();
	if ($page['type'] == 'blog') {
		\Avos\Scaffold\expandUrlMeta($blog);
	}

	$blog['tags'] = explode(',', $blog['tags']);

	return array(
		'args' => array(
			'blog' => $blog
		)
	);
}
