<?
//
// stores how many clicks to redis as the key 'clicks' then redirects
// copy to the web folder alongside index.php
//
// usage: /click.php/NAME/https://the-url/fish?foo
//
// call /click.php?passwd from a browser to output the stats
//
// to display how many clicks from the command line:
//
// $ php redis.php get clicks
// Array
// (
//    [mysite1/NAME] => 181
//    [mysite2/NAME] => 752
//    [mysite3/NAME] => 253
// )
//
// to nodify the redis key used and/or index in the array define a [tracker] block
// :prefix and :name can be used for both key= and index=
//
// [tracker]
// ; defaults if none defined
// key = clicks
// index = ':prefix/:name'
// passwd = 12345
//
// to reset stats use the cli:
//
// $ php redis.php rmkeys clicks
// deleting 1 keys
// deleting clicks
//

// this line assumes your webroot folder is at the same level as avos
// somewhere/avos/
// somewhere/www/

define('TOP', dirname(dirname(__FILE__)) . '/avos/');
include(TOP . 'bin/bootstrap.php');

//
// parse request
//

$url = $_SERVER['REQUEST_URI'];
$redis = \Avos\Redis\handle();
$name = 'default';
$passwd = getConfig('tracker', 'passwd', '12345');
$stats = 0;

if (preg_match('!^/(.*?)/(.*?)/(http.*)$!', $url, $cap)) {
    $name = $cap[2];
    $url = $cap[3];
}
elseif (preg_match('!(http.*)!', $url, $cap)) {
    $url = $cap[1];
}
else if ($_SERVER['QUERY_STRING'] == $passwd) {
    $stats = 1;
}
else {
    $url = '/';
}

//
// work out redis key adnd array index
//

$prefix = \Avos\Redis\getPrefix();
$key = getConfig('tracker', 'key', 'clicks');
$index = getConfig('tracker', 'index', ':prefix/:name');

$key = str_replace(':prefix', $prefix, $key);
$key = str_replace(':name', $name, $key);

$index = str_replace(':prefix', $prefix, $index);
$index = str_replace(':name', $name, $index);

//
// just dump stats if no args
//

if ($stats) {
    $tot = 0;
    $clicks = $redis->hGetAll($key);
    ksort($clicks);
    echo "<table>";
    foreach ($clicks as $k => $v) {
        echo "<tr><td>$k</td><td>$v</td></tr>";
        $tot += $v;
    }
    echo "<tr><td></td><td>$tot</td></tr>";
    echo "</table>";
    exit;
}

if ($url != '/') {
    $redis->hIncrBy($key, $index, 1);
}

//
// redirect
//

header("Location: $url", true, 302);

